==> kdevelop_5.2.1.orig.tar.xz: kdevelop-5.2.1/plugins/lldb/controllers/variable.h <==
/*
 * LLDB-specific variable
 * Copyright 2016  Aetf <aetf@unlimitedcodeworks.xyz>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LLDB_VARIABLE_H
#define LLDB_VARIABLE_H

#include "mivariable.h"

namespace KDevelop {
class TreeModel;
class TreeItem;
}

namespace KDevMI { namespace LLDB {
class DebugSession;
class LldbVariable : public MIVariable
{
    Q_OBJECT

public:
    LldbVariable(DebugSession *session, KDevelop::TreeModel* model, KDevelop::TreeItem* parent,
                const QString& expression, const QString& display = QLatin1String(""));

    void handleRawUpdate(const MI::ResultRecord &r);

    void refetch();

    using KDevelop::Variable::topLevel;

    // For testing
    using KDevelop::Variable::childCount;
    using KDevelop::Variable::child;

protected:
    void formatChanged() override;
    QString formatValue(const QString &value) const override;
};

} // end of namespace LLDB
} // end of namespace KDevMI

#endif // LLDB_VARIABLE_H

==> kdevelop-5.3.0.tar.xz: kdevelop-5.3.0/plugins/lldb/controllers/variable.h <==
/*
 * LLDB-specific variable
 * Copyright 2016  Aetf <aetf@unlimitedcodeworks.xyz>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License or (at your option) version 3 or any later version
 * accepted by the membership of KDE e.V. (or its successor approved
 * by the membership of KDE e.V.), which shall act as a proxy
 * defined in Section 14 of version 3 of the license.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef LLDB_VARIABLE_H
#define LLDB_VARIABLE_H

#include "mivariable.h"

namespace KDevelop {
class TreeModel;
class TreeItem;
}

namespace KDevMI { namespace LLDB {
class DebugSession;
class LldbVariable : public MIVariable
{
    Q_OBJECT

public:
    LldbVariable(DebugSession *session, KDevelop::TreeModel* model, KDevelop::TreeItem* parent,
                const QString& expression, const QString& display = QString());

    void handleRawUpdate(const MI::ResultRecord &r);

    void refetch();

    using KDevelop::Variable::topLevel;

    // For testing
    using KDevelop::Variable::childCount;
    using KDevelop::Variable::child;

protected:
    void formatChanged() override;
    QString formatValue(const QString &value) const override;
};

} // end of namespace LLDB
} // end of namespace KDevMI

#endif // LLDB_VARIABLE_H
